@@ -13,10 +13,3 @@ class OptionsHelpTable(QtWidgets.QTableWidget):
         super(OptionsHelpTable, self).__init__(parent)
 
         pass
-
-
-if __name__ == "__main__":
-    app = QtWidgets.QApplication(sys.argv)
-    window = OptionsHelpTable()
-    window.show()
-    app.exec()
